pub struct MemoryStorage<C: Crypto, PK, SK, M> { /* private fields */ }Expand description
Keystore implementation which stores the encrypted key in memory.
This is provided mainly for testing in environments where hitting the
filesystem is undesirable, and otherwise equivalent to FileStorage.
Implementations